unit Netdemo;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Ptfunc, Qassign, Queues, Prtsrv, Usfunc,
  Fsfunc, Buttons, Users, Filesrv, NetInfo, Msfunc, Exptfunc, Login, CMap;

type
  TNDemo = class(TForm)
    UserList1: TUserList;
    ServerDetails: TSpeedButton;
    ServerSleep: TSpeedButton;
    ServerWake: TSpeedButton;
    ServerFunctions1: ServerFunctions;
    ServerDown: TSpeedButton;
    UserDetails: TSpeedButton;
    AddNewUser: TSpeedButton;
    DeleteUser: TSpeedButton;
    PrintServers1: TPrintServers;
    PrintQueues1: TPrintQueues;
    QueueAssignments1: QueueAssignments;
    MessageText: TEdit;
    SendMessage: TSpeedButton;
    ReceiveMessage: TSpeedButton;
    MessageMode: TSpeedButton;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Exit: TButton;
    ShowObjects: TSpeedButton;
    Messaging1: Messaging;
    ExpertFunctions1: ExpertFunctions;
    UserFunctions1: UserFunctions;
    PrintServerInformation: TSpeedButton;
    PrintQueueInformation: TSpeedButton;
    PrinterFunctions1: PrinterFunctions;
    AttachFileServer: TSpeedButton;
    DetachFileServer: TSpeedButton;
    Map: TSpeedButton;
    FileServers1: TFileServers;
    procedure Setup(Sender: TObject);
    procedure UpdateAll(Sender: TObject);
    procedure UpdatePrintQueues(Sender: TObject);
    procedure ServerDetailsClick(Sender: TObject);
    procedure UserDetailsClick(Sender: TObject);
    procedure AddNewUserClick(Sender: TObject);
    procedure SendMessageClick(Sender: TObject);
    procedure ReceiveMessageClick(Sender: TObject);
    procedure ExitClick(Sender: TObject);
    procedure MessageModeClick(Sender: TObject);
    procedure ShowObjectsClick(Sender: TObject);
    procedure DeleteUserClick(Sender: TObject);
    procedure SetupForms(Sender: TObject);
    procedure ServerSleepClick(Sender: TObject);
    procedure ServerDownClick(Sender: TObject);
    procedure ServerWakeClick(Sender: TObject);
    procedure PrintServerInformationClick(Sender: TObject);
    procedure PrintQueueInformationClick(Sender: TObject);
    procedure AttachFileServerClick(Sender: TObject);
    procedure MapClick(Sender: TObject);
    procedure DetachFileServerClick(Sender: TObject);
    procedure SetFormFocus(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  NDemo: TNDemo;

implementation

{$R *.DFM}

(********* The procedures below show how to
   invoke the various list box components ***********)

procedure TNDemo.Setup(Sender: TObject);

(* This procedure sets everything going *)

begin

     (* Get the file servers *)

     FileServers1.Active:=True;

     (* Get the print queue assignments for this machine *)

     QueueAssignments1.Active:=True;

     (* Select the first one *)

     QueueAssignments1.ItemIndex:=0;

end;

procedure TNDemo.SetFormFocus(Sender: TObject);
begin

     FileServers1.SetFocus;

end;

procedure TNDemo.SetupForms(Sender: TObject);
begin

     NetInfoBox.Hide;

end;

procedure TNDemo.UpdateAll(Sender: TObject);

(* This routine is called when the current server
   is changed *)

begin

     (* Get the users for the current file server *)

     UserList1.Active:=True;

     (* Select the first one *)

     UserList1.ItemIndex:=0;

     (* Get the print servers for the current file server *)

     PrintServers1.Active:=True;

     (* Select the first one *)

     PrintServers1.ItemIndex:=0;

     (* Get the Queues for the current print server *)

     PrintQueues1.Active:=True;

     (* Select the first one *)

     PrintQueues1.ItemIndex:=0;

end;

procedure TNDemo.UpdatePrintQueues(Sender: TObject);

(* This procedure is called when a different
   print server is selected, it updates the
   queues *)

begin

     (* Get the Queues for the current print server *)

     PrintQueues1.Active:=True;

     (* Select the first one *)

     PrintQueues1.ItemIndex:=0;

end;

(********* Below is a few examples of how to invoke the
   file server functions *******************************)

procedure TNDemo.ServerDetailsClick(Sender: TObject);

(* This procedure gets the file server information *)

var
   n : Integer;

begin

     NetInfoBox.InformationListBox.Visible:=True;
     NetInfoBox.Cancel.Caption:='Statistics';
     NetInfoBox.Cancel.Visible:=True;
     NetInfoBox.MessageOptions.Visible:=False;
     NetInfoBox.AddUserCaption.Visible:=False;
     NetInfoBox.NewUserName.Visible:=False;
     NetInfoBox.AvaliableEntities.Visible:=False;

     (* Clear information box *)

     NetInfoBox.InformationListBox.Clear;

     ServerFunctions1.FileServerFunction:=Details;
     ServerFunctions1.Active:=True;

     For n:=0 to ServerFunctions1.Information.Count-1 do
     begin
        NetInfoBox.InformationListBox.Items.Add(ServerFunctions1.Information[n]);
     end;

     (* Get the volumes for this server *)

     For n:=0 to FileServers1.Volumes.Count-1 do
     begin
        if n=0 then
           NetInfoBox.InformationListBox.Items.Add(
                'Volumes               '+FileServers1.Volumes[n])
        else
           NetInfoBox.InformationListBox.Items.Add(
                '                      '+FileServers1.Volumes[n]);
     end;

     NetInfoBox.Caption:='File Server Information For '+FileServers1.Items[FileServers1.ItemIndex];
     NetInfoBox.ShowModal;
     NetInfoBox.Cancel.Caption:='Cancel';
end;

procedure TNDemo.ServerSleepClick(Sender: TObject);

(* This procedure invokes the ServerSleep function *)

(* ServerSleep is used to close the bindery, mostly for
   archiving.  Once closed, the server is effectively
   asleep, you can however still access it.  If you
   reboot when the server is asleep without waking
   it up first as soon as it realises you have logged
   off it will automatically wake up *)

var

   Response       : Word;

begin

     Response:=MessageDlg('Are you sure you want to put '+FileServers1.Items[FileServers1.ItemIndex]
                           +' to sleep',
                           mtWarning,[mbYes,mbNo],0);

     If Response=mrYes then
     begin

        (* Set the required function *)
        ServerFunctions1.FileServerFunction:=Sleep;

        (* Perform the Sleep function *)

        ServerFunctions1.Active:=True;
        Response:=MessageDlg(FileServers1.Items[FileServers1.ItemIndex]
                             +' is now sleeping like a baby',
                             mtWarning,[mbOK],0);
     end;

end;

procedure TNDemo.ServerWakeClick(Sender: TObject);

(* This procedure wakes a server, if the server
   is not asleep then it will do nothing.  The
   process of waking up a server is to simply
   reopen the bindery *)

begin

      (* Set the required function *)

      ServerFunctions1.FileServerFunction:=WakeUp;

      (* Perform the Wake Up function *)

      ServerFunctions1.Active:=True;

end;

procedure TNDemo.AttachFileServerClick(Sender: TObject);

(* This procedure invokes the Attach Server Function *)

begin

     LoginToServer.ShowModal;

     (* Update the current servers *)

     FileServers1.Active:=True;

     (* Select the first one *)

     FileServers1.ItemIndex:=0;

end;

procedure TNDemo.DetachFileServerClick(Sender: TObject);

(* The following procedure detaches from the current server *)

begin

       ServerFunctions1.FileServerFunction:=Detach;
       ServerFunctions1.Active:=True;

       (* Update the current servers *)

       FileServers1.Active:=True;

       (* Select the first one *)

       FileServers1.ItemIndex:=0;

       (* Update user list *)

       UserList1.Active:=True;

end;

procedure TNDemo.MapClick(Sender: TObject);

(* This procedure changes the current mappings *)

begin
     DriveMappings.ShowModal;
end;

procedure TNDemo.ServerDownClick(Sender: TObject);

(* This procedure shows how to down a file server.
   It goes without saying USE IT WITH CARE! *)

var
   Response : Word;

begin

     (* If this is the only server warn that app will shut down *)

     Response:=mrYes;

     if FileServers1.Items.Count=1 then
        Response:=MessageDlg('By downing this server this demo will have to shut down. Continue?',
                           mtWarning,[mbYes,mbNo],0);

     If Response=mrYes then
     begin
        Response:=MessageDlg('Are you sure you want to down '+
                              FileServers1.Items[FileServers1.ItemIndex],
                              mtWarning,[mbYes,mbNo],0);

        If Response=mrYes then
        begin

            ServerFunctions1.FileServerFunction:=Down;
            ServerFunctions1.Active:=True;
            Response:=MessageDlg(FileServers1.Items[FileServers1.ItemIndex]+' is down',
                                 mtWarning,[mbOK],0);
            If FileServers1.Items.Count=1 then
               Halt;

            (* Re-intialise system *)

            (* Update the current servers *)

            FileServers1.Active:=True;

            (* Select the first one *)

            FileServers1.ItemIndex:=0;

            (* Update user list *)

            UserList1.Active:=True;

            (*Setup(NDemo);*)

         end;

     end;

end;

(********* Below is a few examples of how to invoke the
   user functions **************************************)


procedure TNDemo.UserDetailsClick(Sender: TObject);

(* Get details for the current user. *)

var
   n : Integer;

begin


     NetInfoBox.InformationListBox.Visible:=True;
     NetInfoBox.Cancel.Visible:=False;
     NetInfoBox.MessageOptions.Visible:=False;
     NetInfoBox.AddUserCaption.Visible:=False;
     NetInfoBox.NewUserName.Visible:=False;
     NetInfoBox.AvaliableEntities.Visible:=False;

     (* Can't show specific information for [***] ALL
        as this is a generic user for messaging *)

     (* Clear information box *)

     NetInfoBox.InformationListBox.Clear;

     If UserList1.Items[UserList1.ItemIndex]<>'[***] ALL' then
     begin

       UserFunctions1.Functions:=Detail;

       UserFunctions1.Active:=True;

       For n:=0 to UserFunctions1.Information.Count-1 do
       begin
          NetInfoBox.InformationListBox.Items.Add(UserFunctions1.Information[n]);
       end;
       NetInfoBox.Caption:='User Information For '+UserList1.Items[UserList1.ItemIndex];
       NetInfoBox.ShowModal;
     end;

end;

procedure TNDemo.AddNewUserClick(Sender: TObject);

(* This procedure shows how to use the AddUser
   function.  To use it you will need supervisor
   rights.  This particular version will only
   create the default user profile, although
   we do support other security levels in
   the released version *)

begin

     (* Hide/show objects for the Add user function *)

     NetInfoBox.InformationListBox.Visible:=False;
     NetInfoBox.MessageOptions.Visible:=False;
     NetInfoBox.AvaliableEntities.Visible:=False;
     NetInfoBox.Cancel.Visible:=True;
     NetInfoBox.AddUserCaption.Visible:=True;
     NetInfoBox.NewUserName.Visible:=True;
     NetInfoBox.Caption:='Add A User';
     NetInfoBox.ShowModal;

     (* Do we want to setup a user *)

     If NetInfoBox.ModalResult=mrOK then
     begin
        UserFunctions1.Functions:=AddUser;
        If NetInfoBox.NewUserName.Text<>'' then
            UserFunctions1.Active:=True;
     end;
end;

procedure TNDemo.DeleteUserClick(Sender: TObject);

(* This procedure deletes the current selected user *)

var
   Response : Word;

begin

    (* Confirm this function *)

    Response:=MessageDlg('Do you really want to delete '+
                          Copy(UserList1.Items[UserList1.ItemIndex],7,Length(UserList1.Items[UserList1.ItemIndex])-6)+
                         ' from '+FileServers1.Items[FileServers1.ItemIndex],
                          mtWarning,[mbYes, mbNo],0);

    If Response=mrYes then
    begin

       (* Set the RemoveUser function *)
       UserFunctions1.Functions:=RemoveUser;

       (* Perform the RemoveUser function *)
       UserFunctions1.Active:=True;
    end;

end;

(********* Below is a few examples of how to invoke the
   messaging functions *********************************)


procedure TNDemo.SendMessageClick(Sender: TObject);

(* This procedure sends a message to the
   selected user, it user is [***] ALL
   then this message will be broadcast *)

var
    Response : Word;

begin

     (* Check something to send *)

     If MessageText.Text<>'' then
     begin

          (* Set the message mode *)

          Case NetInfoBox.MessageOptions.ItemIndex of

              0:
                Messaging1.Method:=Normal;
              1:
                Messaging1.Method:=None;
              2:
                Messaging1.Method:=Partial;
              3:
                Messaging1.Method:=Full;

          end;

          (* Set the component message text *)

          Messaging1.Text:=MessageText.Text;

          (* Make sure component in SEND mode *)

          Messaging1.MessageFunction:=Send;

          (* Activate the component *)

          Messaging1.Active:=True;

          (* Inform message went *)

          Response:=MessageDlg('Message sent to '+UserList1.Items[UserList1.ItemIndex],
                               mtInformation,[mbOk],0);


          (* Clear message *)

          MessageText.Text:='';

     end;

end;

procedure TNDemo.ReceiveMessageClick(Sender: TObject);

(* This procedure receives any messages,
   it will get messages that have been sent
   with either the FULL or PARTIAL METHOD.

   Note that the IncommingMessage string list
   will always contain [End of Incomming Messages]
   as the last entry *)

var
   n        : Integer;
   Response : Word;

begin

          (* Set the message mode *)

      Case NetInfoBox.MessageOptions.ItemIndex of

          0:
            Messaging1.Method:=Normal;
          1:
            Messaging1.Method:=None;
          2:
            Messaging1.Method:=Partial;
          3:
            Messaging1.Method:=Full;

      end;


     (* Put the component into RECEIVE mode *)

     Messaging1.MessageFunction:=Receive;

     (* Activate the component *)

     Messaging1.Active:=True;

     (* Display each message, one line at
        a time *)

     for n:=0 to Messaging1.IncommingMessage.Count-1 do
     begin
          Response:=MessageDlg(Messaging1.IncommingMessage[n],
                               mtInformation,[mbOk],0);
     end;

end;

procedure TNDemo.MessageModeClick(Sender: TObject);

(* This procedure allows the messaging mode to
   be changed *)

begin

     (* Hide/show objects for the changing the message mode *)

     NetInfoBox.InformationListBox.Visible:=False;
     NetInfoBox.Cancel.Visible:=False;
     NetInfoBox.AddUserCaption.Visible:=False;
     NetInfoBox.NewUserName.Visible:=False;
     NetInfoBox.AvaliableEntities.Visible:=False;
     NetInfoBox.MessageOptions.Visible:=True;
     NetInfoBox.Caption:='Message Mode';
     NetInfoBox.ShowModal;

end;

(****** Below is some examples of how to invoke
        the printer functions component ********)

procedure TNDemo.PrintServerInformationClick(Sender: TObject);

var
   n : Integer;

begin

     NetInfoBox.InformationListBox.Visible:=True;
     NetInfoBox.Cancel.Visible:=False;
     NetInfoBox.MessageOptions.Visible:=False;
     NetInfoBox.AddUserCaption.Visible:=False;
     NetInfoBox.NewUserName.Visible:=False;
     NetInfoBox.AvaliableEntities.Visible:=False;

     (* Clear information box *)

     NetInfoBox.InformationListBox.Clear;

     PrinterFunctions1.PrinterFunction:=PrintServerDetails;
     PrinterFunctions1.Active:=True;

     For n:=0 to PrinterFunctions1.Information.Count-1 do
     begin
        NetInfoBox.InformationListBox.Items.Add(PrinterFunctions1.Information[n]);
     end;
     NetInfoBox.Caption:='Print Server Information For '+PrintServers1.Items[PrintServers1.ItemIndex];
     NetInfoBox.ShowModal;
     NetInfoBox.Cancel.Caption:='Cancel';
end;


procedure TNDemo.PrintQueueInformationClick(Sender: TObject);

var
   n : Integer;

begin

     NetInfoBox.InformationListBox.Visible:=True;
     NetInfoBox.Cancel.Visible:=False;
     NetInfoBox.MessageOptions.Visible:=False;
     NetInfoBox.AddUserCaption.Visible:=False;
     NetInfoBox.NewUserName.Visible:=False;
     NetInfoBox.AvaliableEntities.Visible:=False;

     (* Clear information box *)

     NetInfoBox.InformationListBox.Clear;

     PrinterFunctions1.PrinterFunction:=QueueDetails;
     PrinterFunctions1.Active:=True;

     For n:=0 to PrinterFunctions1.Information.Count-1 do
     begin
        NetInfoBox.InformationListBox.Items.Add(PrinterFunctions1.Information[n]);
     end;
     NetInfoBox.Caption:='Print Queue Information For '+PrintQueues1.Items[PrintQueues1.ItemIndex];
     NetInfoBox.ShowModal;
     NetInfoBox.Cancel.Caption:='Cancel';

end;


(********* Below is an example of how to invoke the
   expert functions. *******************************)

(* The ExpertFunction VCL is your gateway to anything
   you ever wanted to do.  When we were designing
   this system we produced some easy to use components
   that would enable you to access some basic network
   functions but we realised you would want more.  To
   achieve this and not create 800+ VCL's we designed
   this one, we have predefined lots of functions but
   if you know of one that is not defined in the list
   and you know all the relevant information such
   as input/output formats etc then simply pass this
   information through to our GATEWAY function, and
   we will pass your request on! *)

procedure TNDemo.ShowObjectsClick(Sender: TObject);

(* This procedure uses the Expert Functions to
   display all known objects.  *)

var
   n        : Integer;
   ObjectID : String;

begin

     NetInfoBox.InformationListBox.Clear;

     NetInfoBox.Cancel.Visible:=False;
     NetInfoBox.AddUserCaption.Visible:=False;
     NetInfoBox.NewUserName.Visible:=False;
     NetInfoBox.MessageOptions.Visible:=False;
     NetInfoBox.InformationListBox.Visible:=False;
     NetInfoBox.AvaliableEntities.Visible:=True;
     NetInfoBox.Caption:='Select Required Object';

     NetInfoBox.ShowModal;

     (* OK we now have the required object,
        let's show the list *)

     NetInfoBox.AvaliableEntities.Visible:=False;
     NetInfoBox.InformationListBox.Visible:=True;

     NetInfoBox.InformationListBox.Clear;

     Case NetInfoBox.AvaliableEntities.ItemIndex of

          0:
            begin
              ExpertFunctions1.Entity:=ALL;
              ObjectID:='ALL';
            end;
          1:
            begin
              ExpertFunctions1.Entity:=User;
              ObjectID:='Users';
            end;
          2:
            begin
              ExpertFunctions1.Entity:=UserGroup;
              ObjectID:='User Groups';
            end;
          3:
            begin
              ExpertFunctions1.Entity:=PrintQueue;
              ObjectID:='Print Queues';
            end;
          4:
            begin
              ExpertFunctions1.Entity:=FileServer;
              ObjectID:='File Servers';
            end;
          5:
            begin
              ExpertFunctions1.Entity:=JobServer;
              ObjectID:='Job Servers';
            end;
          6:
            begin
              ExpertFunctions1.Entity:=Gateway;
              ObjectID:='Gateways';
            end;
          7:
            begin
              ExpertFunctions1.Entity:=PrintServer;
              ObjectID:='Print Servers';
            end;
          8:
            begin
              ExpertFunctions1.Entity:=ArchiveQueue;
              ObjectID:='Archive Queues';
            end;
          9:
            begin
              ExpertFunctions1.Entity:=ArchiveServer;
              ObjectID:='Archive Servers';
            end;
          10:
            begin
              ExpertFunctions1.Entity:=JobQueue;
              ObjectID:='Job Queues';
            end;
          11:
            begin
              ExpertFunctions1.Entity:=Administration;
              ObjectID:='Administration Objects';
            end;
          12:
            begin
              ExpertFunctions1.Entity:=RemoteBridge;
              ObjectID:='Remote Bridges';
            end;

     end;

     ExpertFunctions1.ObjectFunction:=GetObjects;
     ExpertFunctions1.Active:=True;

     For n:=0 to ExpertFunctions1.Information.Count-1 do
     begin
        NetInfoBox.InformationListBox.Items.Add(ExpertFunctions1.Information[n]);
     end;

     NetInfoBox.InformationListBox.Sorted:=True;
     If ObjectID='ALL' then
         NetInfoBox.Caption:='All Known Objects'
     else
         NetInfoBox.Caption:='Known '+ObjectID;

     NetInfoBox.ShowModal;
     NetInfoBox.InformationListBox.Sorted:=False;

end;


(* The following procedures are specific to this demo
   and of no interest ********************************)

procedure TNDemo.ExitClick(Sender: TObject);
begin
     Halt;
end;

end.
